# Generated by Django 3.2.5 on 2021-07-18 21:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("sinp_organisms", "0002_auto_20210718_2027"),
    ]

    operations = [
        migrations.AddField(
            model_name="organism",
            name="parent",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="sinp_organisms.organism",
                verbose_name="Organisme parent",
            ),
        ),
    ]



from django.urls import include, path
from rest_framework.routers import SimpleRouter

from .views import OrganismMemberViewset, OrganismViewset

app_name = "sinp_organisms"

router = SimpleRouter(trailing_slash=False)

router.register(r"organisms", OrganismViewset)
router.register(r"members", OrganismMemberViewset)


urlpatterns = [path("organisms/", include(router.urls))]

# urlpatterns = [
#     path(
#         "organisms",
#         OrganismViewset.as_view({"get": "list"}),
#         name="organism_list",
#     ),
#     path(
#         "organisms/<int:pk>",
#         OrganismViewset.as_view({"get": "retrieve"}),
#         name="organism",
#     ),
#     path(
#         "organisms/<int:pk>/members",
#         OrganismMemberViewset.as_view({"get": "list"}),
#         name="organism_member_list",
#     ),
#     path(
#         "organisms/member/<int:pk>",
#         OrganismMemberViewset.as_view({"get": "retrieve"}),
#         name="organism_member",
#     ),
# ]



import logging

# from django.contrib.auth.mixins import LoginRequiredMixin
from rest_framework.permissions import DjangoModelPermissions
from rest_framework.viewsets import ModelViewSet

from .mixins import OrganismsFilteringMixin
from .models import Organism, OrganismMember
from .serializers import OrganismMemberSerializer, OrganismSerializer

logger = logging.getLogger(__name__)


class OrganismViewset(OrganismsFilteringMixin, ModelViewSet):
    serializer_class = OrganismSerializer
    permission_classes = [DjangoModelPermissions]
    queryset = Organism.objects.all()


class OrganismMemberViewset(ModelViewSet):
    serializer_class = OrganismMemberSerializer
    permission_classes = [DjangoModelPermissions]
    queryset = OrganismMember.objects.all()



import logging

from django.db.models import Q

logger = logging.getLogger(__name__)


def set_if_not_none(mapping, key, value):
    if value is not None:
        mapping[key] = value


class OrganismsFilteringMixin:
    """Mixin used for Place lists filtering"""

    def get_queryset(self, *args, **kwargs):
        qs = super().get_queryset()

        label = self.request.query_params.get("label", None)
        uuid = self.request.query_params.get("uuid", None)
        action_scope = self.request.query_params.get("action_scope", None)
        geographic_area = self.request.query_params.get(
            "geographic_area", None
        )
        status = self.request.query_params.get("status", None)
        organism_type = self.request.query_params.get("type", None)
        # member = self.request.query_params.get("member", None)

        logger.info("QUERY_PARAMS %s", self.request.query_params)

        qs = (
            qs.filter(
                Q(label__icontains=label) | Q(short_label__icontains=label)
            )
            if label is not None
            else qs
        )

        qs = qs.filter(uuid=uuid) if uuid is not None else qs

        qs = (
            qs.filter(
                Q(action_scope__mnemonic=action_scope)
                | Q(action_scope__code=action_scope)
            )
            if action_scope is not None
            else qs
        )

        qs = (
            qs.filter(
                Q(geographic_area__mnemonic=geographic_area)
                | Q(geographic_area__code=geographic_area)
            )
            if geographic_area is not None
            else qs
        )

        qs = (
            qs.filter(Q(status__mnemonic=status) | Q(status__code=status))
            if status is not None
            else qs
        )

        qs = (
            qs.filter(Q(type__mnemonic=type) | Q(type__code=type))
            if organism_type is not None
            else qs
        )

        return qs



from django.contrib import admin

# Register your models here.
from .models import Organism, OrganismMember


class OrganismAdmin(admin.ModelAdmin):
    list_display = ("id", "short_label", "status", "type", "action_scope")
    list_filter = ("type",)


class OrganismMemberAdmin(admin.ModelAdmin):
    list_display = (
        "member",
        "organism",
        "member_level",
    )
    list_filter = ("organism", "member_level")


admin.site.register(Organism, OrganismAdmin)
admin.site.register(OrganismMember, OrganismMemberAdmin)



# Generated by Django 3.2.5 on 2021-07-18 20:27

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sinp_nomenclatures", "0001_initial"),
        ("sinp_organisms", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="organism",
            name="action_scope",
            field=models.ForeignKey(
                help_text="Périmètre d'action de l'organisme",
                limit_choices_to={"type__mnemonic": "action_scope"},
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="organism_action_scope",
                to="sinp_nomenclatures.nomenclature",
                verbose_name="Périmètre d'action",
            ),
        ),
        migrations.AlterField(
            model_name="organism",
            name="geographic_area",
            field=models.ForeignKey(
                blank=True,
                help_text="Zone d'action géographique de l'organisme",
                limit_choices_to={"type__mnemonic": "geographic_area"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="organism_geographic_area",
                to="sinp_nomenclatures.nomenclature",
                verbose_name="Zone géographique",
            ),
        ),
        migrations.AlterField(
            model_name="organism",
            name="geographic_area_details",
            field=models.CharField(
                blank=True,
                help_text="Information précisant la zone géographique d'action.",
                max_length=500,
                null=True,
                verbose_name="Détails sur la zone géographique",
            ),
        ),
        migrations.AlterField(
            model_name="organism",
            name="phone_number",
            field=models.CharField(
                blank=True,
                max_length=17,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Les numéros de téléphones doivent être renseignés avec le format :'+999999999'. jusqu'à 15 chiffres sont autorisés",
                        regex="^\\+?1?\\d{9,15}$",
                    )
                ],
                verbose_name="Numéro de téléphone",
            ),
        ),
        migrations.AlterField(
            model_name="organism",
            name="status",
            field=models.ForeignKey(
                help_text="Permet d'indiquer si l'organisme est public ou privé",
                limit_choices_to={"type__mnemonic": "organism_status"},
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="organism_status",
                to="sinp_nomenclatures.nomenclature",
                verbose_name="Statut",
            ),
        ),
        migrations.AlterField(
            model_name="organism",
            name="type",
            field=models.ForeignKey(
                limit_choices_to={"type__mnemonic": "organism_type"},
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="organism_type",
                to="sinp_nomenclatures.nomenclature",
                verbose_name="Type d'organisme",
            ),
        ),
        migrations.AlterField(
            model_name="organismmember",
            name="member_level",
            field=models.ForeignKey(
                limit_choices_to={"type__mnemonic": "member_level"},
                on_delete=django.db.models.deletion.CASCADE,
                related_name="member_level",
                to="sinp_nomenclatures.nomenclature",
                verbose_name="Niveau du membre",
            ),
        ),
    ]



from rest_framework.serializers import ModelSerializer

from .models import Organism, OrganismMember


class OrganismSerializer(ModelSerializer):
    class Meta:
        model = Organism
        fields = [
            "id",
            "uuid",
            "label",
            "short_label",
            "action_scope",
            "geographic_area",
            "geographic_area_details",
            "status",
            "type",
            "address",
            "postal_code",
            "municipality",
            "email",
            "phone_number",
            "url",
            "created_by",
            "updated_by",
            "timestamp_create",
            "timestamp_update",
        ]
        read_only_fields = [
            "created_by",
            "updated_by",
            "timestamp_create",
            "timestamp_update",
            "uuid",
        ]
        depth = 0


class OrganismMemberSerializer(ModelSerializer):
    class Meta:
        model = OrganismMember
        fields = [
            "id",
            "member",
            "member_level",
        ]
        read_only_fields = [
            "created_by",
            "updated_by",
            "timestamp_create",
            "timestamp_update",
        ]
        depth = 1
